@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception qw( -all !lazy );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007005';
+our $VERSION   = '0.007006';
 
 use B ();
 
@@ -192,10 +192,14 @@ sub BUILD {
 
     if ( $self->is eq 'lazy' ) {
         $self->lazy( true );
-        $self->builder( true ) unless $self->has_builder;
+        $self->builder( true ) unless $self->has_builder || $self->has_default;
         $self->is( ro );
     }
 
+    if ( $self->has_builder and $self->has_default ) {
+        croak "Attribute cannot have both default and builder.";
+    }
+
     for my $property ( 'builder', 'trigger' ) {
         if ( CodeRef->check( $self->$property ) ) {
             $self->$property( true );
@@ -267,6 +271,13 @@ sub clone {
     delete $inherit{coderef_default_variable};
     delete $inherit{_order};
 
+    # Allow child class to switch from default to builder
+    # or vice versa.
+    if ( exists $args{builder} or exists $args{default} ) {
+        delete $inherit{builder};
+        delete $inherit{default};
+    }
+
     return ref($self)->new( %inherit, %args );
 }
 
@@ -412,16 +423,18 @@ sub has_simple_default {
 sub _compile_check {
     my ( $self, $varname ) = @_;
 
-    my $type = $self->type;
+    my $type  = $self->type;
 
     if ( $self->compiling_class
     and  $self->compiling_class->imported_functions->{blessed} ) {
-        if ( $type == Object ) {
+        my $ctype = $type->find_constraining_type;
+
+        if ( $ctype == Object ) {
             return "blessed( $varname )";
         }
-        elsif ( $type->isa( 'Type::Tiny::Class' ) ) {
+        elsif ( $ctype->isa( 'Type::Tiny::Class' ) ) {
             return sprintf 'blessed( %s ) && %s->isa( %s )',
-                $varname, $varname, $self->_q( $type->class );
+                $varname, $varname, $self->_q( $ctype->class );
         }
     }
 
