@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007005";
+    our $MITE_VERSION = "0.007006";
 
     BEGIN {
         require Scalar::Util;
@@ -124,13 +124,8 @@
 
         # Attribute source (type: Mite::Source)
         if ( exists $args->{"source"} ) {
-            (
-                do {
-                    use Scalar::Util ();
-                    Scalar::Util::blessed( $args->{"source"} )
-                      and $args->{"source"}->isa(q[Mite::Source]);
-                }
-              )
+            blessed( $args->{"source"} )
+              && $args->{"source"}->isa("Mite::Source")
               or croak "Type check failed in constructor: %s should be %s",
               "source", "Mite::Source";
             $self->{"source"} = $args->{"source"};
