@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007005";
+    our $MITE_VERSION = "0.007006";
 
     BEGIN {
         require Scalar::Util;
@@ -96,13 +96,7 @@
         # Attribute source (type: Mite::Source)
         croak "Missing key in constructor: source"
           unless exists $args->{"source"};
-        (
-            do {
-                use Scalar::Util ();
-                Scalar::Util::blessed( $args->{"source"} )
-                  and $args->{"source"}->isa(q[Mite::Source]);
-            }
-          )
+        blessed( $args->{"source"} ) && $args->{"source"}->isa("Mite::Source")
           or croak "Type check failed in constructor: %s should be %s",
           "source", "Mite::Source";
         $self->{"source"} = $args->{"source"};
@@ -355,10 +349,10 @@
 
         @_ == 2
           or croak(
-            "Wrong number of parameters in signature for %s: %s, got %d",
+            "Wrong number of parameters in signature for %s: got %d, %s",
             "_source_file2compiled_file",
-            "expected exactly 2 parameters",
-            scalar(@_)
+            scalar(@_),
+            "expected exactly 2 parameters"
           );
 
         @head = splice( @_, 0, 1 );
