@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007005";
+    our $MITE_VERSION = "0.007006";
 
     BEGIN {
         require Scalar::Util;
@@ -66,13 +66,8 @@
 
         # Attribute config (type: Mite::Config)
         if ( exists $args->{"config"} ) {
-            (
-                do {
-                    use Scalar::Util ();
-                    Scalar::Util::blessed( $args->{"config"} )
-                      and $args->{"config"}->isa(q[Mite::Config]);
-                }
-              )
+            blessed( $args->{"config"} )
+              && $args->{"config"}->isa("Mite::Config")
               or croak "Type check failed in constructor: %s should be %s",
               "config", "Mite::Config";
             $self->{"config"} = $args->{"config"};
@@ -240,13 +235,8 @@
                 $_[0]{"config"} = do {
                     my $default_value =
                       $Mite::Project::__config_DEFAULT__->( $_[0] );
-                    (
-                        do {
-                            use Scalar::Util ();
-                            Scalar::Util::blessed($default_value)
-                              and $default_value->isa(q[Mite::Config]);
-                        }
-                      )
+                    blessed($default_value)
+                      && $default_value->isa("Mite::Config")
                       or croak( "Type check failed in default: %s should be %s",
                         "config", "Mite::Config" );
                     $default_value;
@@ -298,11 +288,9 @@
         my ( @out, %tmp, $tmp, $dtmp, @head );
 
         @_ == 3
-          or croak(
-            "Wrong number of parameters in signature for %s: %s, got %d",
-            "_recurse_directory", "expected exactly 3 parameters",
-            scalar(@_)
-          );
+          or
+          croak( "Wrong number of parameters in signature for %s: got %d, %s",
+            "_recurse_directory", scalar(@_), "expected exactly 3 parameters" );
 
         @head = splice( @_, 0, 1 );
 
@@ -386,11 +374,9 @@
 
         @_ == 2 && ( ref( $_[1] ) eq 'HASH' )
           or @_ % 2 == 1 && @_ >= 7 && @_ <= 15
-          or croak(
-            "Wrong number of parameters in signature for %s: %s, got %d",
-            "inject_mite_functions", "that does not seem right",
-            scalar(@_)
-          );
+          or
+          croak( "Wrong number of parameters in signature for %s: got %d, %s",
+            "inject_mite_functions", scalar(@_), "that does not seem right" );
 
         @head = splice( @_, 0, 1 );
 
@@ -526,11 +512,9 @@
         my ( %tmp, $tmp, @head );
 
         @_ >= 2 && @_ <= 3
-          or croak(
-            "Wrong number of parameters in signature for %s: %s, got %d",
-            "load_files", "expected exactly 2 parameters",
-            scalar(@_)
-          );
+          or
+          croak( "Wrong number of parameters in signature for %s: got %d, %s",
+            "load_files", scalar(@_), "expected exactly 2 parameters" );
 
         @head = splice( @_, 0, 1 );
 
