@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007005";
+    our $MITE_VERSION = "0.007006";
 
     BEGIN {
         require Scalar::Util;
@@ -116,13 +116,8 @@
 
         # Attribute source (type: Mite::Source)
         if ( exists $args->{"source"} ) {
-            (
-                do {
-                    use Scalar::Util ();
-                    Scalar::Util::blessed( $args->{"source"} )
-                      and $args->{"source"}->isa(q[Mite::Source]);
-                }
-              )
+            blessed( $args->{"source"} )
+              && $args->{"source"}->isa("Mite::Source")
               or croak "Type check failed in constructor: %s should be %s",
               "source", "Mite::Source";
             $self->{"source"} = $args->{"source"};
@@ -528,13 +523,7 @@
     sub source {
         @_ > 1
           ? do {
-            (
-                do {
-                    use Scalar::Util ();
-                    Scalar::Util::blessed( $_[1] )
-                      and $_[1]->isa(q[Mite::Source]);
-                }
-              )
+            blessed( $_[1] ) && $_[1]->isa("Mite::Source")
               or croak( "Type check failed in %s: value should be %s",
                 "accessor", "Mite::Source" );
             $_[0]{"source"} = $_[1];
@@ -554,11 +543,9 @@
         my ( @out, %tmp, $tmp, $dtmp, @head );
 
         @_ >= 1
-          or croak(
-            "Wrong number of parameters in signature for %s: %s, got %d",
-            "add_attributes", "expected exactly 1 parameters",
-            scalar(@_)
-          );
+          or
+          croak( "Wrong number of parameters in signature for %s: got %d, %s",
+            "add_attributes", scalar(@_), "expected exactly 1 parameters" );
 
         @head = splice( @_, 0, 1 );
 
